import unittest


class BaseTest(unittest.TestCase):
	responses = {}

	@staticmethod
	def putResponse(name,response):
		BaseTest.responses[name] = response


	@staticmethod
	def resolveResponseValue(overrideValue):
		pos = overrideValue.find('.')

		name = overrideValue[:pos]
		print "Example Name: %s" % name
		key = overrideValue[pos+1:]
		print "Key Name: %s" % key


		if name in BaseTest.responses:
			response = BaseTest.responses[name].getObject()
			if key in response:
				return response[key]
			else:
				print "Key:'%s' is not found in the response" % key
		else:
			print "Example:'%s' is not found in the response" % name

		return None

	def customAssertValue(self,expected,actual):
		if (isinstance(actual,float)):
			self.assertEqual(float(expected), actual)
		else:
			self.assertEqual(expected.lower(), str(actual).lower())











#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#

import unittest
from mastercardapicore import RequestMap, Config, OAuthAuthentication
from os.path import dirname, realpath, join
from base_test import BaseTest
from mastercardaudiences import *


class AudiencesSegmentTest(BaseTest):

    def setUp(self):
        keyFile = join(dirname(realpath(__file__)),"resources","mcapi_sandbox_key.p12")
        auth = OAuthAuthentication("L5BsiPgaF-O3qA36znUATgQXwJB6MRoMSdhjd7wt50c97279!50596e52466e3966546d434b7354584c4975693238513d3d",keyFile, "alias", "password")
        Config.setAuthentication(auth)
        Config.setDebug(True)

    
        
        
        
        
        
        
                
    def test_example_audience_request(self):
        mapObj = RequestMap()
        mapObj.set("PageLength", "10")
        mapObj.set("PageOffset", "1")
        mapObj.set("ZipRangeStart", "000000000")
        mapObj.set("ZipRangeEnd", "999999999")
        mapObj.set("Segment", "Standard_000001")
        mapObj.set("DecileIDRangeStart", "1")
        mapObj.set("DecileIDRangeEnd", "20")
        

        

        response = AudiencesSegment.query(mapObj)
        self.customAssertValue("1", response.get("Response.PageOffset"))
        self.customAssertValue("98", response.get("Response.TotalCount"))
        self.customAssertValue("311125860", response.get("Response.ArrayOfAudience[0].Audience.Zip"))
        self.customAssertValue("Standard_000001", response.get("Response.ArrayOfAudience[0].Audience.Segment"))
        self.customAssertValue("20", response.get("Response.ArrayOfAudience[0].Audience.Demidecile"))
        

        BaseTest.putResponse("example_audience_request", response);

    
        
    

if __name__ == '__main__':
    unittest.main()




#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


from mastercardapicore import BaseObject, RequestMap


class AudiencesSegment(BaseObject):
    """
    
    """

    def getResourcePath(self,action):
        """
        Returns the resource path based on the action
        @return str
        """
        action = action.upper()
        
        if action == "QUERY":
            return "/audiences/v1/audiences/audiencesegment"
        
        raise Exception("Invalid action supplied: "+ action)


    def getHeaderParams(self,action):
        """
        Returns a list containing header params
        @return list
        """
        action = action.upper()
        
        if action == "QUERY":
            return []
        
        raise Exception("Invalid action supplied: "+ action)


    def getQueryParams(self,action):
        """
        Returns a list containing query params
        @return list
        """
        action = action.upper()
        
        if action == "QUERY":
            return ["PageOffset","PageLength","ZipRangeStart","ZipRangeEnd","Segment","DecileIDRangeStart","DecileIDRangeEnd"]
        
        raise Exception("Invalid action supplied: "+ action)


    @classmethod
    def getApiVersion(cls):
        return "1.0.1"






    @classmethod
    def query(cls,criteria):
        """
        Query objects of type AudiencesSegment by id and optional criteria
        @param type criteria
        @return AudiencesSegment object representing the response.
        """

        return super(AudiencesSegment,cls).queryObject(AudiencesSegment(criteria))



